modelicares.simres.info — ModelicaRes v0.7.1 Documentation
Description: Python module to set up, plot, and analyze Modelica simulations
Keywords: Modelica, Python, plot, results, simulation, experiment

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »

# `modelicares.simres.info`

Aliases to the “get” methods in `modelicares.SimRes`

Example:

    >>> from modelicares import SimRes
    >>> from modelicares.simres.info import *

    >>> sim = SimRes('examples/ChuaCircuit.mat')
    >>> values(sim, 'L.v')
    array([  0.00000000e+00, ... -2.53528625e-01], dtype=float32)

This is the same as

    >>> sim.get_values('L.v')
    array([  0.00000000e+00, ... -2.53528625e-01], dtype=float32)

`modelicares.simres.info.` `FV` = <unbound method SimRes.get_FV>

  Alias for `SimRes.get_FV()`

`modelicares.simres.info.` `IV` = <unbound method SimRes.get_IV>

  Alias for `SimRes.get_IV()`

`modelicares.simres.info.` `description` = <unbound method SimRes.get_description>

  Alias for `SimRes.get_description()`

`modelicares.simres.info.` `displayUnit` = <unbound method SimRes.get_displayUnit>

  Alias for `SimRes.get_displayUnit()`

`modelicares.simres.info.` `indices_wi_times` = <unbound method SimRes.get_indices_wi_times>

  Alias for `SimRes.get_indices_wi_times()`

`modelicares.simres.info.` `times` = <unbound method SimRes.get_times>

  Alias for `SimRes.get_times()`

`modelicares.simres.info.` `unit` = <unbound method SimRes.get_unit>

  Alias for `SimRes.get_unit()`

`modelicares.simres.info.` `values` = <unbound method SimRes.get_values>

  Alias for `SimRes.get_values()`

`modelicares.simres.info.` `values_at_times` = <unbound method SimRes.get_values_at_times>

  Alias for `SimRes.values_at_times()`

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »